#!/bin/sh
# Run an m-file inside MATLAB from the command line.
${MATLAB} -nodisplay -r "\
  javaaddpath('${builddir}'); \
  try; \
    run('${abs_srdir}/${1}'); \
    ret = 0; \
  catch ex; \
    ret = 1; \
    disp(ex.getReport()); \
  end; \
  exit(ret);"
